@@ -6,6 +6,7 @@ use crate::host::{Host, Instance, PolarIterator};
 use crate::{FromPolar, PolarValue};
 
 use polar_core::events::*;
+use polar_core::roles_validation::ResultEvent;
 use polar_core::terms::*;
 
 impl Iterator for Query {
@@ -31,6 +32,10 @@ impl Query {
         }
     }
 
+    pub fn source(&self) -> String {
+        self.inner.source_info()
+    }
+
     pub fn next_result(&mut self) -> Option<crate::Result<ResultSet>> {
         loop {
             let event = self.inner.next()?;
@@ -70,11 +75,6 @@ impl Query {
                     instance,
                     class_tag,
                 } => self.handle_external_isa(call_id, instance, class_tag),
-                QueryEvent::ExternalUnify {
-                    call_id,
-                    left_instance_id,
-                    right_instance_id,
-                } => self.handle_external_unify(call_id, left_instance_id, right_instance_id),
                 QueryEvent::ExternalIsSubSpecializer {
                     call_id,
                     instance_id,
@@ -232,17 +232,6 @@ impl Query {
         Ok(())
     }
 
-    fn handle_external_unify(
-        &mut self,
-        call_id: u64,
-        left_instance_id: u64,
-        right_instance_id: u64,
-    ) -> crate::Result<()> {
-        let res = self.host.unify(left_instance_id, right_instance_id)?;
-        self.question_result(call_id, res)?;
-        Ok(())
-    }
-
     fn handle_external_is_subspecializer(
         &mut self,
         call_id: u64,
@@ -278,7 +267,7 @@ impl ResultSet {
     ) -> crate::Result<Self> {
         // Check for expression.
         for term in bindings.values() {
-            if term.value().as_expression().is_ok() {
+            if term.value().as_expression().is_ok() && !host.accept_expression {
                 return Err(OsoError::Custom {
                     message: r#"
 Received Expression from Polar VM. The Expression type is not yet supported in this language.
@@ -317,6 +306,10 @@ This may mean you performed an operation in your policy over an unbound variable
             .ok_or(crate::OsoError::FromPolar)
             .and_then(T::from_polar)
     }
+
+    pub fn into_event(self) -> ResultEvent {
+        ResultEvent::new(self.bindings)
+    }
 }
 
 impl std::fmt::Debug for ResultSet {
